@@ -1,6 +1,6 @@
 (* camlp5r pa_extend.cmo pa_fstream.cmo q_MLast.cmo *)
-(* $Id: pa_extprint.ml 1822 2007-12-28 12:58:30Z deraugla $ *)
-(* Copyright (c) INRIA 2007-2008 *)
+(* $Id: pa_extprint.ml,v 1.49 2010/02/19 09:06:35 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2010 *)
 
 open Pcaml;
 
@@ -90,7 +90,8 @@ value conv loc (p, wo, e) =
     if wo = None && catch_any p then <:expr< fun $p$ -> Some $e$ >>
     else <:expr< fun [ $p$ $opt:wo$ -> Some $e$ | _ -> None ] >>
   in
-  <:expr< ($tst$, False, $e$) >>
+  let has_when = if wo <> None then <:expr< True >> else <:expr< False >> in
+  <:expr< ($tst$, $has_when$, $e$) >>
 ;
 
 value text_of_extprint loc el =
