@@ -1,6 +1,6 @@
 (* camlp5r pa_extend.cmo q_MLast.cmo *)
-(* $Id: pa_o.ml 1898 2008-02-08 19:09:42Z deraugla $ *)
-(* Copyright (c) INRIA 2007-2008 *)
+(* $Id: pa_o.ml,v 1.84 2010/02/19 09:06:35 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2010 *)
 
 open Pcaml;
 
@@ -26,6 +26,7 @@ do {
   Grammar.Unsafe.clear_entry let_binding;
   Grammar.Unsafe.clear_entry type_declaration;
   Grammar.Unsafe.clear_entry constructor_declaration;
+  Grammar.Unsafe.clear_entry label_declaration;
   Grammar.Unsafe.clear_entry match_case;
   Grammar.Unsafe.clear_entry with_constr;
   Grammar.Unsafe.clear_entry poly_variant;
@@ -149,7 +150,7 @@ value infixop0 =
     (parser
        [: `("", x)
            when
-             not (List.mem x excl) && String.length x >= 2 &&
+             not (List.mem x excl) && (x = "$" || String.length x >= 2) &&
              List.mem x.[0] list && symbolchar x 1 :] ->
          x)
 ;
@@ -341,7 +342,8 @@ value choose_tvar tpl =
 EXTEND
   GLOBAL: sig_item str_item ctyp patt expr module_type module_expr class_type
     class_expr class_sig_item class_str_item let_binding type_declaration
-    constructor_declaration match_case with_constr poly_variant;
+    constructor_declaration label_declaration match_case with_constr
+    poly_variant;
   module_expr:
     [ [ "functor"; "("; i = V UIDENT "uid" ""; ":"; t = module_type; ")";
         "->"; me = SELF ->
@@ -712,7 +714,8 @@ EXTEND
               match p2 with
               [ <:patt< ( $list:pl$ ) >> ->
                   List.fold_left (fun p1 p2 -> <:patt< $p1$ $p2$ >>) p1 pl
-              | _ -> <:patt< $p1$ $p2$ >> ] ] ]
+              | _ -> <:patt< $p1$ $p2$ >> ] ]
+      | "lazy"; p = SELF -> <:patt< lazy $p$ >> ]
     | LEFTA
       [ p1 = SELF; "."; p2 = SELF -> <:patt< $p1$ . $p2$ >> ]
     | "simple"
