@@ -1,6 +1,6 @@
 (* camlp5r pa_macro.cmo q_MLast.cmo -qmod ctyp,Type *)
-(* $Id: pa_pragma.ml 1804 2007-12-27 10:30:24Z deraugla $ *)
-(* Copyright (c) INRIA 2007-2008 *)
+(* $Id: pa_pragma.ml,v 1.63 2010/02/19 09:06:35 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2010 *)
 
 (* expressions evaluated in the context of the preprocessor *)
 (* syntax at toplevel: #pragma <expr> *)
@@ -629,7 +629,10 @@ value val_tab = do {
      ("MLast.ExLid",
       fun loc ->
         let t1 = <:ctyp< MLast.loc >> in
-        let t2 = <:ctyp< string >> in
+        let t2 =
+          IFDEF STRICT THEN <:ctyp< Ploc.vala string >>
+          ELSE <:ctyp< string >> END
+        in
         {ctyp = <:ctyp< $t1$ -> $t2$ -> MLast.expr >>;
          expr = Obj.repr (fun loc s -> MLast.ExLid loc s);
          patt eval_patt env pl param =
@@ -894,6 +897,12 @@ value val_tab = do {
         {ctyp = <:ctyp< Ploc.t -> exn -> _ >>;
          expr = Obj.repr Ploc.raise;
          patt = no_patt loc});
+     ("Ploc.VaVal",
+      fun loc ->
+        let ta = ty_var () in
+        {ctyp = <:ctyp< $ta$ -> Ploc.vala $ta$ >>;
+         expr = Obj.repr (fun x -> Ploc.VaVal x);
+         patt = no_patt loc});
      ("prerr_endline",
       fun loc ->
         {ctyp = <:ctyp< string -> unit >>;
