@@ -1,6 +1,6 @@
 (* camlp5r -I . pa_macro.cmo q_MLast.cmo pa_extfun.cmo pa_extprint.cmo pa_pprintf.cmo *)
-(* $Id: pr_r.ml 1896 2008-01-23 12:46:58Z deraugla $ *)
-(* Copyright (c) INRIA 2007-2008 *)
+(* $Id: pr_r.ml,v 1.186 2010/02/19 09:06:36 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2010 *)
 
 open Pretty;
 open Pcaml;
@@ -355,7 +355,7 @@ value record_binding pc (p, e) =
         (fun () -> pprintf pc "%p =@;%p" (hlist patt) pl expr_wh e)
         (fun () -> pprintf pc "%p = do {@;%p@ }" (hlist patt) pl sequence el)
   | None ->
-      pprintf pc "%p =@;%p" (hlist patt) pl expr_wh e ]
+      pprintf pc "%p =@;%p" (hlist patt) pl (comm_expr expr_wh) e ]
 ;
 
 (* Pretty printing improvements (optional):
@@ -605,7 +605,7 @@ value rec get_else_if =
 value if_then force_vertic curr pc (e1, e2) =
   let expr_wh = if flag_where_in_sequences.val then expr_wh else expr in
   horiz_vertic_if force_vertic
-    (fun () -> pprintf pc "if %p then %p" curr e1 curr e2)
+    (fun () -> pprintf pc "if %p then %p" curr e1 (comm_expr curr) e2)
     (fun () ->
        let if_e1_then pc () = pprintf pc "@[<3>if %p@]@ then" curr e1 in
        match sequencify e2 with
@@ -939,9 +939,15 @@ EXTEND_PRINTER
                    let loc = MLast.loc_of_expr ge in
                    curr pc <:expr< do { $list:el$ } >>
                | None ->
-                   pprintf pc "let %s%pin@ %p" (if rf then "rec " else "")
-                     (vlist2 let_binding (and_before let_binding)) pel
-                     (comm_expr expr_wh) e ])
+                   if flag_horiz_let_in.val then
+                     pprintf pc "let %s%pin@ %p" (if rf then "rec " else "")
+                       (vlist2 let_binding (and_before let_binding)) pel
+                       (comm_expr expr_wh) e
+                   else
+                     pprintf pc "@[<b>let %s%pin@ %p@]"
+                       (if rf then "rec " else "")
+                       (vlist2 let_binding (and_before let_binding)) pel
+                       (comm_expr expr_wh) e ])
       | <:expr< let module $uid:s$ = $me$ in $e$ >> ->
           pprintf pc "@[<a>let module %s =@;%p@ in@]@ %p" s module_expr me
             curr e
@@ -1341,7 +1347,10 @@ EXTEND_PRINTER
       | <:str_item< $exp:e$ >> ->
           expr pc e
       | <:str_item< class type $list:_$ >> | <:str_item< class $list:_$ >> ->
-          failwith "classes and objects not pretty printed; add pr_ro.cmo" ] ]
+          failwith "classes and objects not pretty printed; add pr_ro.cmo"
+      | MLast.StUse _ fn sl ->
+          let pc = {(pc) with aft = ""} in
+          pprintf pc "" ] ]
   ;
   pr_sig_item:
     [ "top"
@@ -1378,7 +1387,10 @@ EXTEND_PRINTER
       | <:sig_item< value $lid:s$ : $t$ >> ->
           pprintf pc "value %p :@;%p" var_escaped s ctyp t
       | <:sig_item< class type $list:_$ >> | <:sig_item< class $list:_$ >> ->
-          failwith "classes and objects not pretty printed; add pr_ro.cmo" ] ]
+          failwith "classes and objects not pretty printed; add pr_ro.cmo"
+      | MLast.SgUse _ fn sl ->
+          let pc = {(pc) with aft = ""} in
+          pprintf pc "" ] ]
   ;
   pr_module_expr:
     [ "top"
