@@ -1,6 +1,6 @@
 (* camlp5r pa_macro.cmo q_MLast.cmo *)
-(* $Id: ast2pt.ml 1891 2008-01-22 17:32:21Z deraugla $ *)
-(* Copyright (c) INRIA 2007-2008 *)
+(* $Id: ast2pt.ml,v 1.70 2010/04/28 17:00:42 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2010 *)
 
 open MLast;
 open Parsetree;
@@ -14,7 +14,21 @@ THEN
 END;
 
 IFDEF
-  OCAML_3_10 OR OCAML_3_10_0 OR OCAML_3_10_1 OR OCAML_3_10_2 OR OCAML_3_11 
+  OCAML_3_12_0
+THEN
+  DEFINE AFTER_OCAML_3_12
+END;
+
+IFDEF
+  OCAML_3_11 OR OCAML_3_11_0 OR OCAML_3_11_1 OR OCAML_3_11_2 OR
+  AFTER_OCAML_3_12
+THEN
+  DEFINE AFTER_OCAML_3_11
+END;
+
+IFDEF
+  OCAML_3_10 OR OCAML_3_10_0 OR OCAML_3_10_1 OR OCAML_3_10_2 OR
+  OCAML_3_10_3 OR AFTER_OCAML_3_11
 THEN
   DEFINE AFTER_OCAML_3_10
 END;
@@ -232,7 +246,7 @@ and meth_list loc fl v =
       [mkfield loc (Pfield lab (ctyp (mkpolytype t))) :: meth_list loc fl v] ]
 ;
 
-IFDEF OCAML_3_11 THEN
+IFDEF AFTER_OCAML_3_11 THEN
   value mktype loc tl cl tk pf tm =
     let (params, variance) = List.split tl in
     {ptype_params = List.map uv params; ptype_cstrs = cl; ptype_kind = tk;
@@ -264,7 +278,7 @@ value mkvariant (loc, c, tl) =
 value type_decl tl priv cl =
   fun
   [ TyMan loc t <:ctyp< { $list:ltl$ } >> ->
-      IFDEF OCAML_3_11 THEN
+      IFDEF AFTER_OCAML_3_11 THEN
         mktype loc tl cl (Ptype_record (List.map mktrecord ltl)) priv
           (Some (ctyp t))
       ELSE
@@ -272,7 +286,7 @@ value type_decl tl priv cl =
           (Some (ctyp t))
       END
   | TyMan loc t <:ctyp< [ $list:ctl$ ] >> ->
-      IFDEF OCAML_3_11 THEN
+      IFDEF AFTER_OCAML_3_11 THEN
         mktype loc tl cl (Ptype_variant (List.map mkvariant ctl)) priv
           (Some (ctyp t))
       ELSE
@@ -280,7 +294,7 @@ value type_decl tl priv cl =
           (Some (ctyp t))
       END
   | TyRec loc ltl ->
-      IFDEF OCAML_3_11 THEN
+      IFDEF AFTER_OCAML_3_11 THEN
         mktype loc tl cl (Ptype_record (List.map mktrecord (uv ltl))) priv
           None
       ELSE
@@ -288,7 +302,7 @@ value type_decl tl priv cl =
           None
       END
   | TySum loc ctl ->
-      IFDEF OCAML_3_11 THEN
+      IFDEF AFTER_OCAML_3_11 THEN
         mktype loc tl cl (Ptype_variant (List.map mkvariant (uv ctl))) priv
           None
       ELSE
@@ -303,7 +317,7 @@ value type_decl tl priv cl =
             else None
         | _ -> Some (ctyp t) ]
       in
-      IFDEF OCAML_3_11 THEN
+      IFDEF AFTER_OCAML_3_11 THEN
         mktype (loc_of_ctyp t) tl cl Ptype_abstract priv m
       ELSE
         mktype (loc_of_ctyp t) tl cl Ptype_abstract m
@@ -396,11 +410,11 @@ value mkwithc =
   [ WcTyp loc id tpl pf ct ->
       let (params, variance) = List.split (uv tpl) in
       let tk =
-        IFDEF OCAML_3_08 OR OCAML_3_11 THEN Ptype_abstract
+        IFDEF OCAML_3_08 OR AFTER_OCAML_3_11 THEN Ptype_abstract
         ELSE if uv pf then Ptype_private else Ptype_abstract END
       in
       (long_id_of_string_list loc (uv id),
-       IFDEF OCAML_3_11 THEN
+       IFDEF AFTER_OCAML_3_11 THEN
          let pf = if uv pf then Private else Public in
          Pwith_type
            {ptype_params = List.map uv params; ptype_cstrs = [];
@@ -458,7 +472,7 @@ value rec patt =
             [ <:patt< $uid:s$ >> ->
                 Ppat_construct (mkli (conv_con s) [i :: il]) None
                   (not no_constructors_arity.val)
-            | _ -> error (loc_of_patt p2) "uppercase identifier expected" ]
+            | _ -> error (loc_of_patt p2) "bad access pattern" ]
         | _ -> error (loc_of_patt p2) "bad pattern" ]
       in
       mkpat loc p
@@ -505,6 +519,12 @@ value rec patt =
   | PaInt loc _ _ -> error loc "special int not impl in patt"
   | PaFlo loc s -> mkpat loc (Ppat_constant (Const_float (uv s)))
   | PaLab loc _ _ -> error loc "labeled pattern not allowed here"
+  | PaLaz loc p ->
+      IFDEF AFTER_OCAML_3_11 THEN
+        mkpat loc (Ppat_lazy (patt p))
+      ELSE
+        error loc "lazy patterns not in this version"
+      END
   | PaLid loc s -> mkpat loc (Ppat_var (uv s))
   | PaOlb loc _ _ -> error loc "labeled pattern not allowed here"
   | PaOrp loc p1 p2 -> mkpat loc (Ppat_or (patt p1) (patt p2))
@@ -515,7 +535,12 @@ value rec patt =
           let c2 = char_of_char_token loc2 (uv c2) in
           mkrangepat loc c1 c2
       | _ -> error loc "range pattern allowed only for characters" ]
-  | PaRec loc lpl -> mkpat loc (Ppat_record (List.map mklabpat (uv lpl)))
+  | PaRec loc lpl ->
+      IFDEF AFTER_OCAML_3_12 THEN
+        mkpat loc (Ppat_record (List.map mklabpat (uv lpl)) Closed)
+      ELSE
+        mkpat loc (Ppat_record (List.map mklabpat (uv lpl)))
+      END
   | PaStr loc s ->
       mkpat loc
         (Ppat_constant (Const_string (string_of_string_token loc (uv s))))
@@ -987,14 +1012,26 @@ and class_str_item c l =
   match c with
   [ CrCtr loc t1 t2 -> [Pcf_cstr (ctyp t1, ctyp t2, mkloc loc) :: l]
   | CrDcl loc cl -> List.fold_right class_str_item (uv cl) l
-  | CrInh loc ce pb -> [Pcf_inher (class_expr ce) (uv pb) :: l]
+  | IFDEF AFTER_OCAML_3_12 THEN
+      CrInh loc ce pb -> [Pcf_inher Fresh (class_expr ce) (uv pb) :: l]
+    ELSE
+      CrInh loc ce pb -> [Pcf_inher (class_expr ce) (uv pb) :: l]
+    END
   | CrIni loc e -> [Pcf_init (expr e) :: l]
   | CrMth loc s b e t ->
       let t = option (fun t -> ctyp (mkpolytype t)) (uv t) in
       let e = mkexp loc (Pexp_poly (expr e) t) in
-      [Pcf_meth (uv s, mkprivate (uv b), e, mkloc loc) :: l]
+      IFDEF AFTER_OCAML_3_12 THEN
+        [Pcf_meth (uv s, mkprivate (uv b), Fresh, e, mkloc loc) :: l]
+      ELSE
+        [Pcf_meth (uv s, mkprivate (uv b), e, mkloc loc) :: l]
+      END
   | CrVal loc s b e ->
-      [Pcf_val (uv s, mkmutable (uv b), expr e, mkloc loc) :: l]
+      IFDEF AFTER_OCAML_3_12 THEN
+        [Pcf_val (uv s, mkmutable (uv b), Fresh, expr e, mkloc loc) :: l]
+      ELSE
+        [Pcf_val (uv s, mkmutable (uv b), expr e, mkloc loc) :: l]
+      END
   | CrVir loc s b t ->
       [Pcf_virt (uv s, mkprivate (uv b), ctyp (mkpolytype t), mkloc loc) ::
          l] ]
