@@ -1,6 +1,6 @@
 (* camlp5r pa_extend.cmo q_MLast.cmo *)
-(* $Id: pa_r.ml 1812 2007-12-27 19:50:50Z deraugla $ *)
-(* Copyright (c) INRIA 2007-2008 *)
+(* $Id: pa_r.ml,v 1.121 2010/02/19 09:06:38 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2010 *)
 
 open Pcaml;
 
@@ -27,6 +27,7 @@ do {
   Grammar.Unsafe.clear_entry let_binding;
   Grammar.Unsafe.clear_entry type_declaration;
   Grammar.Unsafe.clear_entry constructor_declaration;
+  Grammar.Unsafe.clear_entry label_declaration;
   Grammar.Unsafe.clear_entry match_case;
   Grammar.Unsafe.clear_entry with_constr;
   Grammar.Unsafe.clear_entry poly_variant;
@@ -119,7 +120,8 @@ value mkident i : string = i;
 EXTEND
   GLOBAL: sig_item str_item ctyp patt expr module_type module_expr class_type
     class_expr class_sig_item class_str_item let_binding type_declaration
-    constructor_declaration match_case ipatt with_constr poly_variant;
+    constructor_declaration label_declaration match_case ipatt with_constr
+    poly_variant;
   module_expr:
     [ [ "functor"; "("; i = V UIDENT "uid" ""; ":"; t = module_type; ")";
         "->"; me = SELF ->
@@ -385,7 +387,8 @@ EXTEND
     | NONA
       [ p1 = SELF; ".."; p2 = SELF -> <:patt< $p1$ .. $p2$ >> ]
     | LEFTA
-      [ p1 = SELF; p2 = SELF -> <:patt< $p1$ $p2$ >> ]
+      [ p1 = SELF; p2 = SELF -> <:patt< $p1$ $p2$ >>
+      | "lazy"; p = SELF -> <:patt< lazy $p$ >> ]
     | LEFTA
       [ p1 = SELF; "."; p2 = SELF -> <:patt< $p1$ . $p2$ >> ]
     | "simple"
