@@ -1,6 +1,6 @@
 (* camlp5r pa_extend.cmo pa_extend_m.cmo q_MLast.cmo *)
-(* $Id: q_MLast.ml 1812 2007-12-27 19:50:50Z deraugla $ *)
-(* Copyright (c) INRIA 2007-2008 *)
+(* $Id: q_MLast.ml,v 1.125 2010/02/19 09:06:38 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2010 *)
 
 value gram = Grammar.gcreate (Plexer.gmake ());
 
@@ -145,6 +145,8 @@ value type_declaration = Grammar.Entry.create gram "type_declaration";
 value match_case = Grammar.Entry.create gram "match_case";
 value constructor_declaration =
   Grammar.Entry.create gram "constructor_declaration";
+value label_declaration =
+  Grammar.Entry.create gram "label_declaration";
 
 value with_constr = Grammar.Entry.create gram "with_constr";
 value poly_variant = Grammar.Entry.create gram "poly_variant";
@@ -260,7 +262,8 @@ value mkident i = Qast.Str i;
 EXTEND
   GLOBAL: sig_item str_item ctyp patt expr module_type module_expr class_type
     class_expr class_sig_item class_str_item let_binding type_declaration
-    constructor_declaration match_case ipatt with_constr poly_variant;
+    constructor_declaration label_declaration match_case ipatt with_constr
+    poly_variant;
   module_expr:
     [ [ "functor"; "("; i = SV UIDENT; ":"; t = module_type; ")"; "->";
         me = SELF ->
@@ -747,7 +750,8 @@ EXTEND
     | NONA
       [ p1 = SELF; ".."; p2 = SELF -> Qast.Node "PaRng" [Qast.Loc; p1; p2] ]
     | LEFTA
-      [ p1 = SELF; p2 = SELF -> Qast.Node "PaApp" [Qast.Loc; p1; p2] ]
+      [ p1 = SELF; p2 = SELF -> Qast.Node "PaApp" [Qast.Loc; p1; p2]
+      | "lazy"; p = SELF -> Qast.Node "PaLaz" [Qast.Loc; p] ]
     | LEFTA
       [ p1 = SELF; "."; p2 = SELF -> Qast.Node "PaAcc" [Qast.Loc; p1; p2] ]
     | "simple"
