@@ -4,7 +4,7 @@
 (*                                                                     *)
 (*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         *)
 (*                                                                     *)
-(*  Copyright 2007 Institut National de Recherche en Informatique et   *)
+(*  Copyright 1996 Institut National de Recherche en Informatique et   *)
 (*  en Automatique.  All rights reserved.  This file is distributed    *)
 (*  under the terms of the Q Public License version 1.0.               *)
 (*                                                                     *)
@@ -130,8 +130,10 @@ and type_declaration =
 
 and type_kind =
     Ptype_abstract
-  | Ptype_variant of (string * core_type list) list * private_flag
-  | Ptype_record of (string * mutable_flag * core_type) list * private_flag
+  | Ptype_variant of (string * core_type list * Location.t) list * private_flag
+  | Ptype_record of
+      (string * mutable_flag * core_type * Location.t) list * private_flag
+  | Ptype_private
 
 and exception_declaration = core_type list
 
@@ -150,7 +152,7 @@ and class_signature = core_type * class_type_field list
 
 and class_type_field =
     Pctf_inher of class_type
-  | Pctf_val   of (string * mutable_flag * core_type option * Location.t)
+  | Pctf_val of (string * mutable_flag * virtual_flag * core_type * Location.t)
   | Pctf_virt  of (string * private_flag * core_type * Location.t)
   | Pctf_meth  of (string * private_flag * core_type * Location.t)
   | Pctf_cstr  of (core_type * core_type * Location.t)
@@ -177,6 +179,7 @@ and class_structure = pattern * class_field list
 
 and class_field =
     Pcf_inher of class_expr * string option
+  | Pcf_valvirt of (string * mutable_flag * core_type * Location.t)
   | Pcf_val   of (string * mutable_flag * expression * Location.t)
   | Pcf_virt  of (string * private_flag * core_type * Location.t)
   | Pcf_meth  of (string * private_flag * expression * Location.t)
