@@ -1,6 +1,6 @@
 (* camlp5r pa_macro.cmo *)
-(* $Id: rprint.ml 1927 2009-05-23 09:04:13Z deraugla $ *)
-(* Copyright (c) INRIA 2007-2008 *)
+(* $Id: rprint.ml,v 1.28 2010/02/19 09:06:41 deraugla Exp $ *)
+(* Copyright (c) INRIA 2007-2010 *)
 
 open Format;
 open Outcometree;
@@ -11,7 +11,9 @@ THEN
   DEFINE OCAML_3_08
 END;
 
-IFDEF OCAML_3_11 OR OCAML_3_11_0 OR OCAML_3_11_1 OR OCAML_3_12_0 THEN
+IFDEF OCAML_3_11 OR OCAML_3_11_0 OR OCAML_3_11_1 OR OCAML_3_11_2 OR
+  OCAML_3_12_0
+THEN
   DEFINE AFTER_OCAML_3_11
 END;
 
